//
// Interface with Nodejitsu's API to get and create databases!
//

var engines = require("./engines");
var request = require("request");

// use Nodejitsu's api to request a list of databases
var list = exports.list = function (opts, cb) {
    request({
        "uri": opts.url + "/databases/" + opts.username + "/"
    }, function (err, resp, body) {
        if (err || resp.statusCode !== 200 ) {
            cb(err || new Error("HTML Status " + response.statusCode));
        }

        cb(null, JSON.parse(body));
    });
}

// tell nodejitsu to make you a new db
var create = exports.create = function (opts, cb) {
    request.post({
        "uri": opts.url + "/databases/" + opts.username + "/" + opts.name,
        "json": { "type": engines.type(opts.type) }
    }, function (err, resp, body) {
        if (err && resp.statusCode !== 201) {
            cb(err || new Error("HTML Status " + response.statusCode));
        }

        // body returns "true"
        cb(null, JSON.parse(body));
    });
}

// Given a db object from the rest api, build up the db's url
var db2url = exports.db2url = function (db) {
    switch (db.type) {
        case "mongo":
            return db.metadata.config.MONGOHQ_URL
                .replace("/undefined", "");
        case "redis":
            return "redis://nodejitsu:" + db.metadata.password
                + "@" + db.metadata.label.split('-')[0] + ".redistogo.com:"
                + db.metadata.port;
        case "couch":
            //TODO: Handle case where couch has password
            return "http://" + db.metadata.id.split("/")[1] 
                + ".couchone.com:5984";
        default:
            break;
    }
}
