var databases = require("./databases");

var engines = {
    "couch": { "type": "couch"},
    "mongo": { "type": "mongo" },
    "redis": { "type": "redis" }
}


engines.cradle = {
    "type": "couch",
    "driver": function(opts, db, cb) {
        var cradle = require("cradle");

        var host = opts.url.split(":");
        var port = host[host.length - 1];
        host = host.slice(0, host.length-1).join(":");

        cb( new cradle.Connection(host, port) );
    }
}

engines.mongoose = {
    "type": "mongo",
    "driver": function (opts, db, cb) {
        var mongoose = require("mongoose");

        // connects to the mongoose for you, returns the connected Mongoose object
        mongoose.connect(opts.url);
        mongoose.on("open", function () {
            cb(mongoose);
        });
    }
}

engines.node_redis = {
    "type": "redis",
    "driver": function (opts, db, cb) {
        var redis = require("redis");

        var host = opts.url.split(":");
        var port = host[host.length - 1];
        host = host.slice(0, host.length-1).join(":");

        var client = redis.createClient(port, host);
        client.on("ready", function () {
            cb(client);
        });
    }
}

// Return the underlying database type
exports.type = function (e) {
    return engines[e].type;
}

exports.engine = function (opts, db, cb) {
    var e = opts.type;

    if (engines[e].driver) {

        // I just want a url.
        if (!opts.url) {
            opts.url = db2url(db);
        }

        engines[e].driver(opts, db, cb);
    } else {
        // Default "just return the url" behavior
        cb(databases.db2url(db));
    }
}
